#
# spec file for package perl-Log-Any
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Log-Any
Name:           perl-Log-Any
Version:        1.718.0
Release:        1.1
# 1.718 -> normalize -> 1.718.0
%define cpan_version 1.718
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Bringing loggers and listeners together
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PR/PREACTION/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Log::Any) = %{version}
Provides:       perl(Log::Any::Adapter) = %{version}
Provides:       perl(Log::Any::Adapter::Base) = %{version}
Provides:       perl(Log::Any::Adapter::Capture) = %{version}
Provides:       perl(Log::Any::Adapter::File) = %{version}
Provides:       perl(Log::Any::Adapter::Multiplex) = %{version}
Provides:       perl(Log::Any::Adapter::Null) = %{version}
Provides:       perl(Log::Any::Adapter::Stderr) = %{version}
Provides:       perl(Log::Any::Adapter::Stdout) = %{version}
Provides:       perl(Log::Any::Adapter::Syslog) = %{version}
Provides:       perl(Log::Any::Adapter::Test) = %{version}
Provides:       perl(Log::Any::Adapter::Util) = %{version}
Provides:       perl(Log::Any::Manager) = %{version}
Provides:       perl(Log::Any::Proxy) = %{version}
Provides:       perl(Log::Any::Proxy::Null) = %{version}
Provides:       perl(Log::Any::Proxy::Test) = %{version}
Provides:       perl(Log::Any::Proxy::WithStackTrace) = %{version}
Provides:       perl(Log::Any::Test) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
'Log::Any' provides a standard log production API for modules.
Log::Any::Adapter allows applications to choose the mechanism for log
consumption, whether screen, file or another logging mechanism like
Log::Dispatch or Log::Log4perl.

Many modules have something interesting to say. Unfortunately there is no
standard way for them to say it - some output to STDERR, others to 'warn',
others to custom file logs. And there is no standard way to get a module to
start talking - sometimes you must call a uniquely named method, other
times set a package variable.

This being Perl, there are many logging mechanisms available on CPAN. Each
has their pros and cons. Unfortunately, the existence of so many mechanisms
makes it difficult for a CPAN author to commit his/her users to one of
them. This may be why many CPAN modules invent their own logging or choose
not to log at all.

To untangle this situation, we must separate the two parts of a logging
API. The first, _log production_, includes methods to output logs (like
'$log->debug') and methods to inspect whether a log level is activated
(like '$log->is_debug'). This is generally all that CPAN modules care
about. The second, _log consumption_, includes a way to configure where
logging goes (a file, the screen, etc.) and the code to send it there. This
choice generally belongs to the application.

A CPAN module uses 'Log::Any' to get a log producer object. An application,
in turn, may choose one or more logging mechanisms via Log::Any::Adapter,
or none at all.

'Log::Any' has a very tiny footprint and no dependencies beyond Perl 5.8.1,
which makes it appropriate for even small CPAN modules to use. It defaults
to 'null' logging activity, so a module can safely log without worrying
about whether the application has chosen (or will ever choose) a logging
mechanism.

See http://www.openswartz.com/2007/09/06/standard-logging-api/ for the
original post proposing this module.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md README
%license LICENSE

%changelog
* Mon Jun  2 2025 Tina Müller <timueller+perl@suse.de>
- updated to 1.718.0 (1.718)
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.718     2025-06-01 09:59:59-05:00 America/Chicago
    [Fixed]
  - Fixed Log::Any::Adapter::Multiplex not loading its child adapter
    modules.
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Aug 18 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.717
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.717     2023-08-17 10:52:21-05:00 America/Chicago
    [Fixed]
  - Fixed WithStackTrace proxy to remove arguments in-place instead of
    always stringifying the exception object immediately. This means we
    need to handle different exception objects differently, but it also
    means a better log message. Thanks @larryl and @GrantStreetGroup for
    submitting this fix! [Github #100]
* Tue Jun 27 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.716
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.716     2023-06-26 14:14:46-05:00 America/Chicago
    [Added]
  - Added a parameter to show stack trace arguments when using the
    WithStackTrace proxy. Since these arguments may contain sensitive
    information, they are now removed by default. Thanks @sam-ng and
    @GrantStreetGroup for submitting this patch! [Github #97]
* Fri May  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.715
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.715     2023-05-04 13:09:22-05:00 America/Chicago
    [Fixed]
  - Fixed Multiplex adapter losing context details. Normally, the
    Log::Any::Proxy joins all of the arguments passed in to a logging
    method if the adapter it's using does not support structured data.
    Multiplex supports structured data, but one of the adapters inside
    may not. So, the Multiplex adapter must also perform this
    concatenation to avoid losing those additional arguments.
    Thanks @jrubinator and @GrantStreetGroup for discovering this bug
    and providing the fix! [Github #95]
* Tue Mar 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.714
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.714     2023-03-20 11:48:30-05:00 America/Chicago
    [Fixed]
  - Fixed Syslog adaptor losing ident and facility information if
    another library wrongly calls Sys::Syslog::closelog(). This is not
    a perfect solution, but a perfect solution can only ever be to fix
    the close that's calling closelog() :P
    Thanks to Tom Christiansen and @GrantStreetGroup for reporting this
    issue and providing the fix.
* Mon Dec 12 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.713
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.713     2022-12-12 12:44:52-06:00 America/Chicago
    [Fixed]
  - Fixed tests failing due to missing Devel::Stacktrace. This is an
    optional module, so we do not explicitly depend on it. Thanks
    @dbevans and @perlpunk for reporting this issue! (Github #93)
  1.712     2022-12-09 11:05:10-06:00 America/Chicago
    [Added]
  - Added `Log::Any::Proxy::WithStackTrace` to provide a stack trace at
    the caller site. Thanks @larryl and @GrantStreetGroup for providing
    this feature!
    [Other]
  - Removed Travis, as they stopped supporting free Github repos :(
* Wed Nov 23 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.711
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.711     2022-11-22 11:28:01-06:00 America/Chicago
    [Fixed]
  - Fixed proxy not exposing 'category' attribute (#86). Thanks
    @andrew-grechkin!
  - Fixed not being able to get a proxy for the "root" category (empty
    string) (#90). Thanks @XSven!
* Tue Aug  3 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.710
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.710     2021-08-02 10:11:33-05:00 America/Chicago
    [Other]
  - Removed explicit declaration of core dependencies to improve user
    experience
* Thu Feb 18 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.709
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.709     2021-02-17 15:16:20-06:00 America/Chicago
    [Added]
  - Added "Log::Any->has_consumer" for the rare case where one needs
    to know if a consumer has already been configured.
* Tue Jan 14 2020 <timueller+perl@suse.de>
- updated to 1.708
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.708     2020-01-12 22:56:43-05:00 America/New_York
    [Added]
  - Added 'Capture' adapter for capturing log messages in an array or
    running an arbitrary callback. This makes it easier to test log
    messages, collect messages from a certain scope for later display.
    Thanks @nrdvana! [Github #77]
  - Added Log::Any::Adapter 'get' class method to get an adapter for
    a category. This allows bypassing the Proxy and using the Adapter
    directly. Doing so breaks all the features enabled by a Proxy, and
    so should only be used in special circumstances (definitely not in
    CPAN modules). Thanks @nrdvana! [Github #78]
  - Added 'Multiplex' adapter for directing log output to one or more
    Log::Any adapters. This allows, for example, basic logging to
    Stderr and logging to a remote Syslogd or Elastic. Thanks
    @jrubinator and @GrantStreetGroup for contributing this!
    [Github #79, Github #16]
* Fri Aug  3 2018 coolo@suse.com
- updated to 1.707
  see /usr/share/doc/packages/perl-Log-Any/Changes
* Sun Jul  8 2018 coolo@suse.com
- updated to 1.706
  see /usr/share/doc/packages/perl-Log-Any/Changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.705
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.705     2018-01-17 13:49:22-06:00 America/Chicago
    [Fixed]
  - Fixed the `binmode` attribute of the File adapter not working
    properly. Thanks @MadLord80! [Github #71]
  1.704     2017-12-17 18:13:33-06:00 America/Chicago
    [Fixed]
  - Fixed some invalid POD and added a test to ensure POD validity
    before release. Thanks @shlomif! [Github #67][Github #68]
  - Improved performance when no work needed to be done. Thanks
    @mephinet! [Github #70]
* Thu Dec  7 2017 coolo@suse.com
- updated to 1.703
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.703     2017-11-29 10:56:17-06:00 America/Chicago
    [Fixed]
  - Fixed log format methods (errorf, warnf, infof, etc...) not
    returning the formatted message sometimes. Thanks @vshekun!
    [Github #64]
* Wed Nov 29 2017 coolo@suse.com
- updated to 1.702
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.702     2017-11-28 15:18:40-06:00 America/Chicago
    [Fixed]
  - Fixed log output disappearing when the `default_adapter` is set.
    Thanks @dallaylaen! [Github #65]
* Tue Oct  3 2017 coolo@suse.com
- updated to 1.701
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.701     2017-10-02 14:36:51-05:00 America/Chicago
    [Fixed]
  - Fixed more method aliases in Log::Any::Adapter::Syslog that were
    mapped to invalid syslog priorities. Thanks @legaultp for the
    patch!
* Fri Sep 29 2017 coolo@suse.com
- updated to 1.700
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.700     2017-09-28 16:59:22-05:00 America/Chicago
    [Fixed]
  - Fixed version of Log::Any::Adapter::Syslog so that installing it
    will also install the rest of Log-Any.
  - Fixed method aliasing in Log::Any::Adapter::Syslog for "error"
    log method. Thanks @legaultp for the patch!
  1.051     2017-08-06 20:41:53-05:00 America/Chicago (TRIAL RELEASE)
    [Fixed]
  - LOG_ANY_DEFAULT_ADAPTER now correctly logs to the given adapter.
    Previously, if no other adapter was set, Log::Any used it's
    default, super-fast "Null" proxy that simply drops all messages
    without checking adapters. Now Log::Any will correctly detect the
    environment variable and create the correct, normal proxy object.
    Thanks @tm604 for the report and @mephinet for the patch!
  1.050     2017-08-03 22:28:37-05:00 America/Chicago (TRIAL RELEASE)
    [Added]
  - Added structured logging to easily log single hash references in
    a parsable format. Thanks @mephinet!
  - Added contextual logging to attach information to log messages
    based on the current context.
    For example, all log messages being generated by a particular HTTP
    request could be logged with the URL, even if they're from a part
    of the application that doesn't know what HTTP is.
    This is very similar to Log::Log4perl's Mapped Diagnostic Context.
    Thanks @mephinet!
* Wed Mar 29 2017 coolo@suse.com
- updated to 1.049
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.049     2017-03-28 16:02:10-05:00 America/Chicago
    [Fixed]
  - Fixed failing tests on Windows because of path separator
    interpolation. Thanks @nanis [Github #56]
  - Added explicit core dependency on Sys::Syslog in case of Perls
    with non-standard core libraries. Thanks @nanis [Github #57]
  1.048     2017-03-27 15:16:12-05:00 America/Chicago
  - No changes since 1.047 trial release
  1.047     2017-03-22 20:22:47-05:00 America/Chicago (TRIAL RELEASE)
    [Fixed]
  - Fixed backwards-compatibility with users using the Unix::Syslog
    macros in Log::Any::Adapter::Syslog. This requires that the user
    have Unix::Syslog installed (which Log::Any does not explicitly
    depend on).
  - Log level aliases are now case-insensitive to match the regular
    log levels. Prior to this, "WARNING", "Warning", and "warning"
    would all work, but "WARN", and "Warn" would not, only "warn".
    Thanks to @0x62ash for reporting this issue. [Github #55]
  - Invalid log levels for the File, Stderr, and Stdout adapters now
    result in a warning, and the default level of "trace" is used.
    Previously, no warning would be issued and no logs would be
    generated. Thanks to @0x62ash for reporting this issue. [Github
    [#55]]
  1.046     2017-01-11 21:22:57-06:00 America/Chicago (TRIAL RELEASE)
    [Added]
  - The Syslog adapter is now part of the core distribution, since it
    relies only on core Perl modules.
* Sun Nov 13 2016 coolo@suse.com
- updated to 1.045
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.045     2016-11-11 21:52:46-06:00 America/Chicago
  - No changes from previous (trial) release 1.044
  1.044     2016-11-06 15:30:35-06:00 America/Chicago (TRIAL RELEASE)
    [Fixed]
  - Imported log object can now be called anything instead of just
    `$log`. This means `use Log::Any '$LOG'` or `use Log::Any '$foo'`
    now work.
  1.043     2016-11-03 21:31:18-05:00 America/Chicago (TRIAL RELEASE)
    [Fixed]
  - Objects that overload stringification are now stringified
    correctly (instead of run through Data::Dumper). Thanks @mephinet!
* Mon Aug 29 2016 coolo@suse.com
- updated to 1.042
  see /usr/share/doc/packages/perl-Log-Any/Changes
* Sun Aug 28 2016 coolo@suse.com
- updated to 1.042
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.042     2016-08-26 23:37:33-05:00 America/Chicago
    [Added]
  - Default adapters can now be configured with arguments (thanks
    @bjakubski!)
  1.041     2016-08-18 00:00:10-05:00 America/Chicago (TRIAL RELEASE)
    [Added]
  - Logging methods now return the formatted log string so that it can
    be used in a `die` or `warn` call.
    [Changed]
  - A new default log proxy (Log::Any::Proxy::Null) is used when there
    are no adapters configured (and so no place for logs to go). This
    proxy does no processing and is about 1000%% percent faster on my
    laptop.
    [Fixed]
  - Suppress 'redundant argument' warnings if too many arguments are
    given to a log formatting string.
* Tue Mar  8 2016 coolo@suse.com
- updated to 1.040
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.040     2016-02-24 17:47:00-05:00 America/New_York
    [Fixed]
  - Fixed duplicated documentation sections.
* Sat Feb 13 2016 coolo@suse.com
- updated to 1.038
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.038     2016-02-10 14:15:31-07:00 America/Mazatlan
  - No changes from 1.037
  1.037     2016-02-05 20:22:34-05:00 America/New_York (TRIAL RELEASE)
    [Fixed]
  - Fixed t/filescreen.t Unicode string tests to use a backwards
    compatible form.  Should fix tests before 5.16.
  1.035     2016-02-04 14:47:20-05:00 America/New_York (TRIAL RELEASE)
    [Changed]
  - The default formatter now replaces a code reference argument with
    the results of calling the code reference ONLY when it is the first
    argument (in place of a format string).  Code references in
    subsequent arguments (to sprintf) are not executed, as this would
    break backwards compatibility.
    [Documented]
  - Noted that repeatedly calling 'set' to set an adapter without calling
    'remove' or using the 'lexically' feature will leak memory.
  1.033     2016-02-03 10:32:57-05:00 America/New_York (TRIAL RELEASE)
    [Added]
  - The default formatter now expands code references.  If the first
    argument is a code reference, it is expanded and returned.  If an
    argument to "sprintf" style formatting is a code reference, it is
    expanded.
    [Changed]
  - The File adapter now opens files with the ":utf8" layer.  It also
    takes a 'binmode' attribute to change the default.
    [Fixed]
  - does_not_contain_ok test adapter function now gives proper
    diagnostic message
  - all diagnostic messages that output the captured log now
    correctly dump the log with pretty formatting
    [Documented]
  - documented the 'proxy_class' argument to `get_logger`
    [~Internal~]
  - Data::Dumper is loaded lazily, to reduce module load times
    for programs that don't need it.
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.032
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.032     2015-03-26 17:23:37-04:00 America/New_York
  - no changes from 1.031
  1.031     2015-03-26 06:08:17-04:00 America/New_York (TRIAL RELEASE)
    [Fixed]
  - Log::Any::Adapter::Test passed through all constructor arguments,
    which could be fatal when mocking adapters without all key-value
    pairs (like Log::Any::Adapter::File); now this only passes through
    the category and ignores other parameters when used as an
    adapter class override.
  1.03      2015-01-01 22:39:41-05:00 America/New_York
    [Changed]
  - Log::Any::Proxy concatenates arguments to basic logging functions
    with a space character before passing them to adapters as a single
    string.  This ensures consistency across adapters that handle
    multiple arguments differently.
  1.02      2014-12-28 07:06:49-05:00 America/New_York
    [Fixed]
  - Some adapters relied on Log::Any::Adapter::Util also loading
    Log::Any so this behavior has been restored.
  1.01      2014-12-26 22:25:13-05:00 America/New_York
    [Fixed]
  - 'numeric_level' was not exported properly from
    Log::Any::Adapter::Util
  1.00      2014-12-25 22:04:13-05:00 America/New_York
    [Added]
  - Logging now goes via a Log::Any::Proxy object instead of directly to
    an adapter. This allows easy customization of the message production.
  - File, Stdout, and Stderr adapters now support a minimum
    log level parameter.
    [Changed]
  - Removed dead code from Log::Any::Adapter::Base; particularly this
    was the formatting code, since this is now handled by
    Log::Any::Proxy.
    [Fixed]
  - File will flock the handle when writing (if flock is avaiable).
  - Won't die if adapters aren't loadable modules as long as they
    provide a constructor.  This allows using private adapters
    defined in another file.
    [Documented]
  - Revised docs for creating adapters
  - Fixed typos and improved docs for Log::Any::Adapter::Util; removed
    stub docs for modules that didn't need it.
    [Deprecated]
  - Deprecated some methods in Log::Any::Adapter::Util
    [Internal]
  - Merged Log-Any and Log-Any-Adapter distributions; reduces code
    duplication and ensures Log::Any and adapter framework stay in sync
  - Eliminates all non-core dependencies (as of Perl 5.8.1), including
    Capture::Tiny, Devel::GlobalDestruction and Guard
  0.92      2014-12-15 07:12:38-05:00 America/New_York (TRIAL RELEASE)
  0.91      2014-12-14 22:13:09-05:00 America/New_York (TRIAL RELEASE)
  0.90      2014-12-12 17:08:22-05:00 America/New_York (TRIAL RELEASE)
* Tue Nov 26 2013 coolo@suse.com
- updated to 0.15
  * Fixes
  - Hide 'package Log::Any::Adapter' from PAUSE/Module::Metadata - miyagawa
- removed patches:
  * noprovides.diff (now upstream)
* Mon Dec 19 2011 coolo@suse.de
- update to 0.14
  * Fixes
  - Fix version number in Log/Any.pm - Stephen Thirlwal
* Tue Aug 23 2011 chris@computersalat.de
- update to 0.13
  * Fixes
  - Fix typo in lib/Log/Any/Adapter/Test.pm - RT #69850 - Stephen Thirlwall
- fix deps
  * 'ExtUtils::MakeMaker' => '6.30'
- rebase noprovides patch
* Tue May 31 2011 coolo@novell.com
- regenerate with newer cpanspec
* Thu Apr  7 2011 coolo@novell.com
- update to 0.12
  * Fixes
  - Return false from null adapter is_xxx methods - RT #64164 - Chip Salzenberg
  - Eliminate 'subroutine redefined' warning in case Log::Any::Adapter loaded before
    Log::Any::Test
  * Implementation
  - Migrate to Dist::Zilla
* Mon Jan 17 2011 coolo@novell.com
- make sure this package does not provide Log::Any::Adapter
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Nov 19 2010 pascal.bleser@opensuse.org
- initial package (0.11)
